@@ -1,11 +1,11 @@
 import pandas as pd
 
-from imodmodel.functions import read
+import imodmodel
 
 
 def test_read(two_contour_model_file):
     """Check that model files can be read."""
-    df = read(two_contour_model_file)
+    df = imodmodel.read(two_contour_model_file)
     assert isinstance(df, pd.DataFrame)
     expected_columns = ['object_id', 'contour_id', 'x', 'y', 'z']
     assert all(col in expected_columns for col in df.columns)
